/*
 * prompt.c: Routines for retrieving and setting a prompt.
 *
 * $Header: /src/packages/kth-krb/SourceRepository/krb4/util/ss/prompt.c,v 1.3 1996/03/10 15:12:54 assar Exp $
 * $Locker:  $
 *
 * Copyright 1987, 1988 by MIT Student Information Processing Board
 *
 * For copyright information, see copyright.h.
 */

#include "copyright.h"
#include <stdio.h>
#include "ss_internal.h"

static const char rcsid[] =
    "$Header: /src/packages/kth-krb/SourceRepository/krb4/util/ss/prompt.c,v 1.3 1996/03/10 15:12:54 assar Exp $";

void ss_set_prompt(int sci_idx, char *new_prompt)
{
     ss_info(sci_idx)->prompt = new_prompt;
}

char *ss_get_prompt(int sci_idx)
{
     return(ss_info(sci_idx)->prompt);
}
